PyFemtet package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   PyFemtet.opt
   PyFemtet.tools

Module contents
---------------

.. automodule:: PyFemtet
   :members:
   :undoc-members:
   :show-inheritance:
